@@ -38,7 +38,7 @@ htmlhelp_basename = 'yamllintdoc'
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    ('index', 'yamllint', 'Linter for YAML files', [u'Adrien Vergé'], 1)
+    ('index', 'yamllint', 'Linter for YAML files', ['Adrien Vergé'], 1)
 ]
 
 # -- Build with sphinx automodule without needing to install third-party libs
