@@ -13,6 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import fileinput
 import os.path
 
 import pathspec
@@ -25,7 +26,7 @@ class YamlLintConfigError(Exception):
     pass
 
 
-class YamlLintConfig(object):
+class YamlLintConfig:
     def __init__(self, content=None, file=None):
         assert (content is None) ^ (file is None)
 
@@ -96,12 +97,31 @@ class YamlLintConfig(object):
             except Exception as e:
                 raise YamlLintConfigError('invalid config: %s' % e)
 
-        if 'ignore' in conf:
-            if not isinstance(conf['ignore'], str):
+        if 'ignore' in conf and 'ignore-from-file' in conf:
+            raise YamlLintConfigError(
+                'invalid config: ignore and ignore-from-file keys cannot be '
+                'used together')
+        elif 'ignore-from-file' in conf:
+            if isinstance(conf['ignore-from-file'], str):
+                conf['ignore-from-file'] = [conf['ignore-from-file']]
+            if not (isinstance(conf['ignore-from-file'], list) and all(
+                    isinstance(ln, str) for ln in conf['ignore-from-file'])):
+                raise YamlLintConfigError(
+                    'invalid config: ignore-from-file should contain '
+                    'filename(s), either as a list or string')
+            with fileinput.input(conf['ignore-from-file']) as f:
+                self.ignore = pathspec.PathSpec.from_lines('gitwildmatch', f)
+        elif 'ignore' in conf:
+            if isinstance(conf['ignore'], str):
+                self.ignore = pathspec.PathSpec.from_lines(
+                    'gitwildmatch', conf['ignore'].splitlines())
+            elif (isinstance(conf['ignore'], list) and
+                    all(isinstance(line, str) for line in conf['ignore'])):
+                self.ignore = pathspec.PathSpec.from_lines(
+                    'gitwildmatch', conf['ignore'])
+            else:
                 raise YamlLintConfigError(
                     'invalid config: ignore should contain file patterns')
-            self.ignore = pathspec.PathSpec.from_lines(
-                'gitwildmatch', conf['ignore'].splitlines())
 
         if 'yaml-files' in conf:
             if not (isinstance(conf['yaml-files'], list)
@@ -135,11 +155,16 @@ def validate_rule_conf(rule, conf):
     if isinstance(conf, dict):
         if ('ignore' in conf and
                 not isinstance(conf['ignore'], pathspec.pathspec.PathSpec)):
-            if not isinstance(conf['ignore'], str):
+            if isinstance(conf['ignore'], str):
+                conf['ignore'] = pathspec.PathSpec.from_lines(
+                    'gitwildmatch', conf['ignore'].splitlines())
+            elif (isinstance(conf['ignore'], list) and
+                    all(isinstance(line, str) for line in conf['ignore'])):
+                conf['ignore'] = pathspec.PathSpec.from_lines(
+                    'gitwildmatch', conf['ignore'])
+            else:
                 raise YamlLintConfigError(
                     'invalid config: ignore should contain file patterns')
-            conf['ignore'] = pathspec.PathSpec.from_lines(
-                'gitwildmatch', conf['ignore'].splitlines())
 
         if 'level' not in conf:
             conf['level'] = 'error'
@@ -150,7 +175,7 @@ def validate_rule_conf(rule, conf):
         options = getattr(rule, 'CONF', {})
         options_default = getattr(rule, 'DEFAULT', {})
         for optkey in conf:
-            if optkey in ('ignore', 'level'):
+            if optkey in ('ignore', 'ignore-from-file', 'level'):
                 continue
             if optkey not in options:
                 raise YamlLintConfigError(
