@@ -218,7 +218,7 @@ ROOT, B_MAP, F_MAP, B_SEQ, F_SEQ, B_ENT, KEY, VAL = range(8)
 labels = ('ROOT', 'B_MAP', 'F_MAP', 'B_SEQ', 'F_SEQ', 'B_ENT', 'KEY', 'VAL')
 
 
-class Parent(object):
+class Parent:
     def __init__(self, type, indent, line_indent=None):
         self.type = type
         self.indent = indent
@@ -341,14 +341,18 @@ def _check(conf, token, prev, next, nextnext, context):
             expected = detect_indent(expected, token)
 
         if found_indentation != expected:
-            yield LintProblem(token.start_mark.line + 1, found_indentation + 1,
-                              'wrong indentation: expected %d but found %d' %
-                              (expected, found_indentation))
+            if expected < 0:
+                message = 'wrong indentation: expected at least %d' % \
+                          (found_indentation + 1)
+            else:
+                message = 'wrong indentation: expected %d but found %d' % \
+                          (expected, found_indentation)
+            yield LintProblem(token.start_mark.line + 1,
+                              found_indentation + 1, message)
 
     if (isinstance(token, yaml.ScalarToken) and
             conf['check-multi-line-strings']):
-        for problem in check_scalar_indentation(conf, token, context):
-            yield problem
+        yield from check_scalar_indentation(conf, token, context)
 
     # Step 2.a:
 
@@ -493,8 +497,8 @@ def _check(conf, token, prev, next, nextnext, context):
                         # indentation it should have (because `spaces` is
                         # `consistent` and its value has not been computed yet
                         # -- this is probably the beginning of the document).
-                        # So we choose an arbitrary value (2).
-                        indent = 2
+                        # So we choose an unknown value (-1).
+                        indent = -1
                     else:
                         indent = detect_indent(context['stack'][-1].indent,
                                                next)
@@ -576,8 +580,7 @@ def _check(conf, token, prev, next, nextnext, context):
 
 def check(conf, token, prev, next, nextnext, context):
     try:
-        for problem in _check(conf, token, prev, next, nextnext, context):
-            yield problem
+        yield from _check(conf, token, prev, next, nextnext, context)
     except AssertionError:
         yield LintProblem(token.start_mark.line + 1,
                           token.start_mark.column + 1,
