@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2017 Johannes F. Knauf
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,8 +17,8 @@
 Use this rule to enforce alphabetical ordering of keys in mappings. The sorting
 order uses the Unicode code point number as a default. As a result, the
 ordering is case-sensitive and not accent-friendly (see examples below).
-This can be changed by setting the global ``locale`` option.  This allows to
-sort case and accents properly.
+This can be changed by setting the global ``locale`` option.  This allows one
+to sort case and accents properly.
 
 .. rubric:: Examples
 
@@ -94,7 +93,7 @@ TYPE = 'token'
 MAP, SEQ = range(2)
 
 
-class Parent(object):
+class Parent:
     def __init__(self, type):
         self.type = type
         self.keys = []
